from .cub import CUB
from .danish_fungi import DanishFungi
from .easy_set import EasySet
from .features_dataset import FeaturesDataset
from .few_shot_dataset import FewShotDataset
from .mini_imagenet import MiniImageNet
from .support_set_folder import SupportSetFolder
from .tiered_imagenet import TieredImageNet
from .wrap_few_shot_dataset import WrapFewShotDataset
